==> sflphone_1.2.0.orig.tar.gz: sflphone-1.2.0/gnome/src/shortcuts.h <==
/*
 *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
 *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef SHORTCUTS_H_
#define SHORTCUTS_H_

#include <gdk/gdkx.h>

typedef struct {
    gchar *action;
    guint key;
    GdkModifierType mask;
    void
    (*callback) (void);
} Accelerator;

void
shortcuts_initialize_bindings ();

void
shortcuts_update_bindings (guint index, guint key, GdkModifierType mask);

void
shortcuts_destroy_bindings ();

Accelerator*
shortcuts_get_list ();

#endif /* SHORTCUTS_H_ */

==> sflphone_1.2.2.orig.tar.gz: sflphone-1.2.2/gnome/src/shortcuts.h <==
/*
 *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
 *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef SHORTCUTS_H_
#define SHORTCUTS_H_

#include <gdk/gdkx.h>

typedef struct {
    gchar *action;
    guint key;
    GdkModifierType mask;
    void (*callback) (gpointer data);
    gpointer data;
} Accelerator;

void
shortcuts_initialize_bindings (GSettings *settings);

void
shortcuts_update_bindings (guint index, guint key, GdkModifierType mask);

void
shortcuts_destroy_bindings ();

Accelerator*
shortcuts_get_list ();

#endif /* SHORTCUTS_H_ */
